@@ -1,6 +1,6 @@
 """A friendly Python Utilitary RPA."""
 
-__version__ = "1.14"
+__version__ = "1.16"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -455,24 +455,33 @@ def create_folder_env(dir_path):
     
     return
 
-def config_logging(file_log="", level=LEVEL, console=True):
+def config_logging(file_log="", level=logging.DEBUG, console=True):
     '''
     Funcion que configura la gestion de Logs
     '''
+    
+    formatter = logging.Formatter('%(asctime)-5s %(filename)s %(lineno)d %(levelname)-8s %(message)s')
+    
     #logging file
     if file_log != "":
-        logging.basicConfig( format = '%(asctime)-5s %(filename)s %(lineno)d %(levelname)-8s %(message)s', level = level, filename = file_log, filemode = "a" )
-    else:
-        logging.basicConfig( format = '%(asctime)-5s %(filename)s %(lineno)d %(levelname)-8s %(message)s', level = level)
+        fh = logging.FileHandler(file_log)
+        fh.setLevel(level=level)
+        fh.setFormatter(formatter)
+    if console:
+        ch = logging.StreamHandler()
+        ch.setLevel(level=level)
+        ch.setFormatter(formatter)
     
     log=logging.getLogger(__name__)
     
-    # logging console
+    if file_log:
+        log.addHandler(fh)
+    
     if console:
-        console = logging.StreamHandler()
-        console.setLevel(level)
-        log.addHandler(console)
-
+        log.addHandler(ch)
+    
+    log.info("Level log: " + logging.getLevelName(level))
+    
     return log
 
 def check_if_string_in_file(filename, string_to_search):
